==> zwap_design_system-0.0.96.tar.gz: lib/assembled/widgets/cards/editProfile/editProfile.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The edit profile state to handle change values inside this card form
class EditProfileState extends ChangeNotifier{

  /// The values mapping
  Map<String, dynamic> values;

  EditProfileState({required this.values});

  /// handle changing data
  void changeData(String key, dynamic newValue){
    this.values[key] = newValue;
    notifyListeners();
  }


}

/// The edit profile card
class EditProfile extends StatelessWidget{

  /// The profile data to edit
  final List<ProfileQuestions> profileQuestions;

  /// The callBack function for the skip button
  final Function() skipButtonCallBack;

  /// The callBack function for the continue button
  final Function() continueButtonCallBack;

  EditProfile({Key? key,
    required this.profileQuestions,
    required this.skipButtonCallBack,
    required this.continueButtonCallBack
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    return VerticalScroll(
        childComponent: CustomCard(
        childComponent: Padding(
          padding: EdgeInsets.only(bottom: 40),
          child: Column(
            children: [
              BlueHeader(
                childrenStack: [
                  FractionalTranslation(
                    translation: const Offset(0.0, 0.5),
                    child: Consumer<ImagePickerState>(
                      builder: (builder, provider, child){
                        return PickImage();
                      }
                    ),
                  )
                ],
                headerHeight: 80,
                stackAlignment: AlignmentDirectional.center,
              ),
              Padding(
                padding: EdgeInsets.only(top: 80),
                child: Consumer<EditProfileState>(
                  builder: (builder, provider, child){
                    return DynamicQuestion(
                        profileQuestions: this.profileQuestions,
                        handleChangeValue: (String key, dynamic value) => provider.changeData(key, value)
                    );
                  }
                ),
              ),
              Padding(
                padding: EdgeInsets.symmetric(vertical: 30, horizontal: 90),
                child: BottomButtons(
                  rightButtonIcon: Icons.group_add_sharp,
                  continueButtonCallBackFunction: () => this.continueButtonCallBack(),
                  continueButtonText: Utils.translatedText('saveButton'),
                  backButtonText: Utils.translatedText('cancelButton'),
                  backButtonCallBackFunction: () => this.skipButtonCallBack(),
                ),
              )
            ],
          ),
        )
    )
    );
  }
}

==> zwap_design_system-0.0.97.tar.gz: lib/assembled/widgets/cards/editProfile/editProfile.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The edit profile state to handle change values inside this card form
class EditProfileState extends ChangeNotifier{

  /// The values mapping
  final Map<String, dynamic> values;

  EditProfileState({required this.values});

  /// handle changing data
  void changeData(String key, dynamic newValue){
    this.values[key] = newValue;
    notifyListeners();
  }


}

/// The edit profile card
class EditProfile extends StatelessWidget{

  /// The profile data to edit
  final List<ProfileQuestions> profileQuestions;

  /// The callBack function for the skip button
  final Function() skipButtonCallBack;

  /// The callBack function for the continue button
  final Function() continueButtonCallBack;

  EditProfile({Key? key,
    required this.profileQuestions,
    required this.skipButtonCallBack,
    required this.continueButtonCallBack
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    return VerticalScroll(
        childComponent: CustomCard(
        childComponent: Padding(
          padding: EdgeInsets.only(bottom: 40),
          child: Column(
            children: [
              BlueHeader(
                childrenStack: [
                  FractionalTranslation(
                    translation: const Offset(0.0, 0.5),
                    child: Consumer<ImagePickerState>(
                      builder: (builder, provider, child){
                        return PickImage();
                      }
                    ),
                  )
                ],
                headerHeight: 80,
                stackAlignment: AlignmentDirectional.center,
              ),
              Padding(
                padding: EdgeInsets.only(top: 80),
                child: Consumer<EditProfileState>(
                  builder: (builder, provider, child){
                    return DynamicQuestion(
                        profileQuestions: this.profileQuestions,
                        handleChangeValue: (String key, dynamic value) => provider.changeData(key, value)
                    );
                  }
                ),
              ),
              Padding(
                padding: EdgeInsets.symmetric(vertical: 30, horizontal: 90),
                child: BottomButtons(
                  rightButtonIcon: Icons.group_add_sharp,
                  continueButtonCallBackFunction: () => this.continueButtonCallBack(),
                  continueButtonText: Utils.translatedText('saveButton'),
                  backButtonText: Utils.translatedText('cancelButton'),
                  backButtonCallBackFunction: () => this.skipButtonCallBack(),
                ),
              )
            ],
          ),
        )
    )
    );
  }
}
